@@ -1,5 +1,5 @@
 #### gen_a_finish fn ####
-gen_a_finish <- function(a_res, my_estimand){
+gen_a_finish <- function(a_res, my_estimand, wts){
 
   if(my_estimand == "ATE"){
     U1 <- stats::rnorm(a_res$n1)*sqrt(a_res$ve1) + a_res$b1*a_res$Rstar_1 +
@@ -14,15 +14,11 @@ gen_a_finish <- function(a_res, my_estimand){
 
     a <- rep(NA, a_res$n)
 
-    expTx = exp(-log(a_res$pi / (1 - a_res$pi)) +
-                  ((a_res$es^2 * (1 - 2*a_res$pi)) / 2) -
-                  (a_res$es * U[ind]))
-    expCntrl = exp(-log(a_res$pi / (1 - a_res$pi)) +
-                     ((a_res$es^2 * (1 - 2*a_res$pi)) / 2) -
-                     (a_res$es * U[-ind]))
+    a[ind] <- 1 / wts[ind] + (1 - (1 / wts[ind])) *
+      (1 / exp(-a_res$es^2 * (1 - 2 * a_res$pi) / 2 + a_res$es * U[ind]))
 
-    a[ind] <- a_res$pi * (1 + expTx)
-    a[-ind] <- (1 - a_res$pi) * (((1 + expCntrl)) / (expCntrl))
+    a[-ind] <- 1 / wts[-ind] + (1 - (1 / wts[-ind])) *
+      (1 / exp(a_res$es^2 * (1 - 2 * a_res$pi) / 2 - a_res$es * U[-ind]))
 
   } else if(my_estimand == "ATT"){
     U0 <- stats::rnorm(a_res$n0)*sqrt(a_res$ve0) + a_res$b0*a_res$Rstar_0 -
@@ -36,9 +32,7 @@ gen_a_finish <- function(a_res, my_estimand){
     a <- rep(NA, a_res$n)
 
     a[ind] = 1
-    a[-ind] = ((1 - a_res$pi) / a_res$pi) * exp((log(a_res$pi / (1 - a_res$pi))) -
-                                                  (a_res$es^2 * (1 - 2*a_res$pi) / 2) +
-                                                  (a_res$es * U[-ind]))
+    a[-ind] = exp(-a_res$es^2 * (1 - 2 * a_res$pi) / 2 + a_res$es * U[-ind])
 
   }  else{
     stop("OVtool currently only works under the ATE or ATT setting.")
